@@ -115,6 +115,12 @@ settings.permalink = '{{category}}/{{filename}}.html'
 settings.perpage = 30
 settings.feedcount = 20
 
+settings.site = {
+    'name': 'Felix Felicis',
+    'url': 'http://github.com',
+    'prefix': '',
+}
+
 settings.author = 'admin'
 settings.authors = {}
 
@@ -131,18 +137,12 @@ settings.writers = {
     'archive_feed': 'liquidluck.writers.core.ArchiveFeedWriter',
     'file': 'liquidluck.writers.core.FileWriter',
     'static': 'liquidluck.writers.core.StaticWriter',
-
-    'year': 'liquidluck.writers.extends.YearWriter',
-    'tag': 'liquidluck.writers.extends.TagWriter',
-    'category': 'liquidluck.writers.extends.CategoryWriter',
-    'category_feed': 'liquidluck.writers.extends.CategoryFeedWriter',
+    'year': 'liquidluck.writers.core.YearWriter',
+    'tag': 'liquidluck.writers.core.TagWriter',
+    'category': 'liquidluck.writers.core.CategoryWriter',
+    'category_feed': 'liquidluck.writers.core.CategoryFeedWriter',
 }
 settings.writers_variables = {}
-
-settings.site = {
-    'name': 'Felix Felicis',
-    'url': 'http://github.com',
-}
 settings.template_variables = {}
 settings.template_filters = {}
 settings.theme_variables = {}
