@@ -9,6 +9,7 @@ Reader, read content, parse to html.
 
 import os
 import logging
+import datetime
 from liquidluck.options import settings, g
 from liquidluck.utils import to_datetime, import_object
 
@@ -112,6 +113,11 @@ class Post(object):
             return to_datetime(date)
         return None
 
+    @property
+    def updated(self):
+        mtime = os.stat(self.filepath).st_mtime
+        return datetime.datetime.fromtimestamp(mtime)
+
     @property
     def public(self):
         return self.meta.get('public', 'true') == 'true'
